@@ -15,8 +15,9 @@ $NAME;
 void ${NAME}_init($NAME *self);
 void ${NAME}_dealloc($NAME *self);
 
-void ${NAME}_resize($NAME *self, size_t capacity);
+void ${NAME}_reserve($NAME *self, size_t capacity);
 void ${NAME}_append($NAME *self, $T elem);
+void ${NAME}_appendEmpty($NAME *self);
 bool ${NAME}_pop($NAME *self, $T *elem);
 void ${NAME}_clear($NAME *self);
 bool ${NAME}_get($NAME *self, size_t index, $T *elem);
