@@ -1,4 +1,4 @@
-import multiprocessing
+import sys, multiprocessing, logging
 from enum import Enum
 
 
@@ -19,10 +19,10 @@ deviceIdx = 0
 
 allowMultiContext = False
 systemLog = False
+logger = None
 
 
 libname = "PuzzleLib"
-cachepath = None
 
 
 globalEvalMode = False
@@ -38,3 +38,19 @@ def isCPUBased(bnd):
 
 def shouldInit():
 	return multiprocessing.current_process().name == "MainProcess" or allowMultiContext
+
+
+def getLogger():
+	global logger
+
+	if logger is not None:
+		return logger
+
+	logger = logging.getLogger(libname)
+	logger.setLevel(logging.DEBUG if systemLog else logging.INFO)
+
+	handler = logging.StreamHandler(stream=sys.stdout)
+	handler.setFormatter(logging.Formatter("[%(name)s] %(message)s"))
+
+	logger.addHandler(handler)
+	return logger
