@@ -1,9 +1,8 @@
-import sys, os
+import sys, os, ctypes
 
 
 def findDNNL():
 	versions = ["1.91", "1.2", "1.1"]
-	error = ""
 
 	if sys.platform == "linux":
 		libnames = ["libdnnl.so.%s" % v for v in versions]
@@ -18,14 +17,21 @@ def findDNNL():
 			os.path.normpath(os.path.join(os.path.dirname(__file__), "../Libs/"))
 		]
 
-		libnames = [os.path.join(lp, "dnnl.dll") for lp in libpaths]
-		error = ": check your DNNL_PATH environment value"
+		libnames = [os.path.join(libpath, "dnnl.dll") for libpath in libpaths]
 
 	else:
 		raise RuntimeError("Unsupported platform for dnnl")
 
-	for libname in libnames:
-		if os.path.exists(libname):
-			return libname
+	cloader = ctypes.windll if sys.platform == "win32" else ctypes.cdll
 
-	raise OSError("dnnl library not found (searched for following version(s): %s)%s" % (versions, error))
+	for libname in libnames:
+		try:
+			clib = cloader.LoadLibrary(libname)
+
+		except OSError:
+			pass
+
+		else:
+			return clib
+
+	raise OSError("dnnl library not found (searched for following version(s): %s)" % versions)
